@@ -12,4 +12,5 @@ ROOT_PATH = sys.path[0]  # 项目根目录
 # 脚本参数
 def argsYaml(args):
     with open(f'{ROOT_PATH}/args.yaml', 'w') as f:
-        yaml.safe_dump(vars(args), f, sort_keys=False)  # 脚本参数yaml保存
+        # 脚本参数yaml保存
+        yaml.safe_dump(vars(args), f, sort_keys=False)
