@@ -21,3 +21,9 @@ def is_logSuffix(logName):
 def log_management(logContent, logName, logSaveMode):
     logFile = open(f'{ROOT_PATH}/{logName}', logSaveMode)  # 日志文件
     logFile.write(logContent)  # 日志写入
+
+
+# 日期时间&帧数
+def date_time_frames(date_time, frames, fdn, fsd):
+    f = open(f'{ROOT_PATH}/date_time_frames.csv', 'a')  # 创建文件
+    f.write(f'{date_time},{frames},{fdn},{fsd}\n')  # 写入
